@@ -11,10 +11,10 @@ PICTURE_FORMATS_DICT = {
 
 
 def get_datetime_object(item):
-    unparsedpubdate = item.find('pubDate').text
+    unparsed_pubdate = item.find('pubDate').text
 
     created_at = datetime.datetime.strptime(
-        unparsedpubdate, "%a, %d %b %Y %H:%M:%S GMT").timetuple()
+        unparsed_pubdate, "%a, %d %b %Y %H:%M:%S GMT").timetuple()
     return datetime.datetime.fromtimestamp(time.mktime(created_at))
 
 
@@ -22,7 +22,7 @@ def get_medialink(item):
     return item.find('enclosure').attrib['url']
 
 
-def install_picture_content_wrap(picture_format, picture_formats, subdirectory, news_item, tempfolder):
+def install_picture_content_wrap(picture_format, picture_formats, subdirectory, news_item, temp_folder):
     # Installs content to LocalIntegratedContent folder and returns mediapath
     if not picture_format in picture_formats:
         return None
@@ -33,7 +33,7 @@ def install_picture_content_wrap(picture_format, picture_formats, subdirectory,
         media_link = media_link.replace('.jpg', '_sqr512.jpg')
 
     media_path = download_media(
-        PICTURE_FORMATS_DICT[picture_format] + media_link, subdirectory, tempfolder)
+        PICTURE_FORMATS_DICT[picture_format] + media_link, subdirectory, temp_folder)
 
     if not check_valid_jpeg(media_path):
         return False
