@@ -7,8 +7,8 @@ from .scalascript import *
 import xml.etree.ElementTree as ET
 from tempfile import gettempdir
 
-tempfolder = gettempdir()
-localintegratedfolder = "C:/Users/Public/Documents/Scala/LocalIntegratedContent"
+temp_folder = gettempdir()
+local_integrated_folder = "C:/Users/Public/Documents/Scala/LocalIntegratedContent"
 
 
 def create_directories(directories):
@@ -39,13 +39,13 @@ def check_valid_jpeg(filepath):
     return imghdr.what(filepath) == 'jpeg' or imghdr.what(filepath) == 'jpg'
 
 
-def download_media(media_link, subdirectory, tempfolder):
+def download_media(media_link, subdirectory, temp_folder):
     # Downloads and returns path of media
     # response = requests.get(media_link, stream=True)
     media_link = media_link
 
     media_filename = media_link.split('/').pop()
-    media_path = os.path.join(tempfolder, subdirectory, media_filename)
+    media_path = os.path.join(temp_folder, subdirectory, media_filename)
 
     if not os.path.exists(media_path):
         response = requests.get(media_link, stream=True)
